@@ -3,7 +3,7 @@ import json
 import logging
 import traceback
 
-from channels.auth import login
+from channels.auth import login, logout
 from channels.db import database_sync_to_async
 
 from .bindings.registry import registered_binding_events
@@ -18,7 +18,6 @@ class AsyncRequest:
     def __init__(self, consumer, text_data):
 
         self.consumer = consumer
-        self.user = consumer.user
 
         payload = json.loads(text_data)
         self.event = payload.get('event', 'error')
@@ -30,6 +29,10 @@ class AsyncRequest:
         if not isinstance(self.data, (list, dict)):
             self.data = {}
 
+    @property
+    def user(self):
+        return self.consumer.user
+
     @property
     def session(self):
         return self.consumer.session
@@ -65,8 +68,7 @@ class AsyncRequest:
     # Respond to the current socket
 
     async def login(self, user):
-        self.user = user
-        self.consumer.user = self.user
+        self.consumer.user = user
         await login(self.consumer.scope, self.user, backend=None)
         self.consumer.scope["session"].save()
         await database_sync_to_async(self.consumer.scope["session"].save)()
@@ -74,16 +76,25 @@ class AsyncRequest:
         user_id = getattr(self.user, 'pk', None) or getattr(self.user, 'id', None) or getattr(self.user, 'key', None) or None
         if user_id:
             await self.subscribe(f'user.{user_id}')
-            await self.reflect('sessionid', getattr(self.session, 'session_key', None))
-        return user
+        await self.reflect(getattr(self.session, 'session_key', None), event="sessionid")
+
+    async def logout(self):
+        user_id = getattr(self.user, 'pk', None) or getattr(self.user, 'id', None) or getattr(self.user, 'key', None) or None
+        await logout(self.consumer.scope)
+        self.consumer.scope["session"].save()
+        await database_sync_to_async(self.consumer.scope["session"].save)()
+        self.consumer.user = self.consumer.scope["user"]
+        if user_id:
+            await self.unsubscribe(f'user.{user_id}')
+        await self.reflect(None, event="sessionid")
 
     async def tunnel(self, stream, method, *args):
-        binding=self.consumer.bindings_by_stream.get(stream)
+        binding = self.consumer.bindings_by_stream.get(stream)
         return await getattr(binding, method)(self, *args)
 
     async def switch(self, stream, method=None, *args):
         if method:
-            binding=self.consumer.bindings_by_stream.get(stream)
+            binding = self.consumer.bindings_by_stream.get(stream)
             return await getattr(binding, method)(self, *args)
 
         else:
@@ -94,13 +105,13 @@ class AsyncRequest:
         return self.consumer.bindings_by_stream.get(stream)
 
     async def reflect(self, data, event=None):
-        message=await encode_json({'event': event or self.event, 'data': data})
+        message = await encode_json({'event': event or self.event, 'data': data})
         await self.consumer.send(text_data=message)
 
     # Respond to the current streamed group attached sockets
     async def dispatch(self, data, stream, event=None):
-        layer=self.consumer.channel_layer
-        message=await encode_json(dict(
+        layer = self.consumer.channel_layer
+        message = await encode_json(dict(
             event=event or self.event,
             data=data
         ))
@@ -111,8 +122,8 @@ class AsyncRequest:
 
     # Respond to all sockets
     async def broadcast(self, data, event=None):
-        layer=self.consumer.channel_layer
-        message=await encode_json(dict(
+        layer = self.consumer.channel_layer
+        message = await encode_json(dict(
             event=event or self.event,
             data=data
         ))
